@@ -1,16 +1,17 @@
-testthat::skip_if_not_installed("ggplot2")
-card1 <- ReportCard$new()
-card1$append_text("Header 2 text", "header2")
-card1$append_text("A paragraph of default text", "header2")
-card1$append_plot(
-  ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Length)) +
-    ggplot2::geom_histogram()
-)
-
-reporter <- Reporter$new()
-reporter$append_cards(list(card1))
-
 testthat::test_that("download_report_button_srv - download a document", {
+  testthat::skip_if_not_installed("ggplot2")
+  rlang::local_options(lifecycle_verbosity = "quiet")
+  card1 <- ReportCard$new()
+  card1$append_text("Header 2 text", "header2")
+  card1$append_text("A paragraph of default text", "header2")
+  card1$append_plot(
+    ggplot2::ggplot(iris, ggplot2::aes(x = Petal.Length)) +
+      ggplot2::geom_histogram(bins = 30)
+  )
+
+  reporter <- teal.reporter::Reporter$new()
+  reporter$append_cards(list(card1))
+
   shiny::testServer(
     download_report_button_srv,
     args = list(
